@@ -1,29 +1,35 @@
 /*  This file is part of the KDE libraries
     SPDX-FileCopyrightText: 1999 Waldo Bastian <bastian@kde.org>
 
-    SPDX-License-Identifier: LGPL-2.0-only
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 // KDE color collection
 
 #include "kcolorcollection.h"
 
-#include <QFile>
 #include <QDir>
-#include <QTextStream>
+#include <QFile>
 #include <QSaveFile>
+#include <QSharedData>
 #include <QStandardPaths>
+#include <QTextStream>
 
-//BEGIN KColorCollectionPrivate
-class KColorCollectionPrivate
+// BEGIN KColorCollectionPrivate
+class KColorCollectionPrivate : public QSharedData
 {
 public:
     KColorCollectionPrivate(const QString &);
-    KColorCollectionPrivate(const KColorCollectionPrivate &);
-    ~KColorCollectionPrivate() {}
+    KColorCollectionPrivate(const KColorCollectionPrivate &) = default;
+    ~KColorCollectionPrivate()
+    {
+    }
     struct ColorNode {
         ColorNode(const QColor &c, const QString &n)
-            : color(c), name(n) {}
+            : color(c)
+            , name(n)
+        {
+        }
         QColor color;
         QString name;
     };
@@ -88,18 +94,11 @@ KColorCollectionPrivate::KColorCollectionPrivate(const QString &_name)
         }
     }
 }
-
-KColorCollectionPrivate::KColorCollectionPrivate(const KColorCollectionPrivate &p)
-    : colorList(p.colorList), name(p.name), desc(p.desc), editable(p.editable)
-{
-}
-//END KColorCollectionPrivate
+// END KColorCollectionPrivate
 
 QStringList KColorCollection::installedCollections()
 {
-    const QStringList paletteDirs = QStandardPaths::locateAll(QStandardPaths::GenericConfigLocation,
-                              QStringLiteral("colors"),
-                              QStandardPaths::LocateDirectory);
+    const QStringList paletteDirs = QStandardPaths::locateAll(QStandardPaths::GenericConfigLocation, QStringLiteral("colors"), QStandardPaths::LocateDirectory);
 
     QStringList paletteList;
     for (const QString &dir : paletteDirs) {
@@ -111,26 +110,18 @@ QStringList KColorCollection::installedCollections()
 }
 
 KColorCollection::KColorCollection(const QString &name)
+    : d(new KColorCollectionPrivate(name))
 {
-    d = new KColorCollectionPrivate(name);
 }
 
-KColorCollection::KColorCollection(const KColorCollection &p)
-{
-    d = new KColorCollectionPrivate(*p.d);
-}
+KColorCollection::KColorCollection(const KColorCollection &p) = default;
 
-KColorCollection::~KColorCollection()
-{
-    // Need auto-save?
-    delete d;
-}
+// Need auto-save?
+KColorCollection::~KColorCollection() = default;
 
-bool
-KColorCollection::save()
+bool KColorCollection::save()
 {
-    QString filename = QStandardPaths::writableLocation(QStandardPaths::GenericConfigLocation) + QLatin1String("/colors/")
-                       + d->name;
+    QString filename = QStandardPaths::writableLocation(QStandardPaths::GenericConfigLocation) + QLatin1String("/colors/") + d->name;
     QSaveFile sf(filename);
     if (!sf.open(QIODevice::WriteOnly)) {
         return false;
@@ -139,11 +130,7 @@ KColorCollection::save()
     QTextStream str(&sf);
 
     QString description = d->desc.trimmed();
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-    description = QLatin1Char('#') + description.split(QLatin1Char('\n'), QString::KeepEmptyParts).join(QLatin1String("\n#"));
-#else
     description = QLatin1Char('#') + description.split(QLatin1Char('\n'), Qt::KeepEmptyParts).join(QLatin1String("\n#"));
-#endif
 
     str << QLatin1String("KDE RGB Palette\n");
     str << description << QLatin1Char('\n');
@@ -191,21 +178,9 @@ int KColorCollection::count() const
     return d->colorList.count();
 }
 
-KColorCollection &
-KColorCollection::operator=(const KColorCollection &p)
-{
-    if (&p == this) {
-        return *this;
-    }
-    d->colorList = p.d->colorList;
-    d->name = p.d->name;
-    d->desc = p.d->desc;
-    d->editable = p.d->editable;
-    return *this;
-}
+KColorCollection &KColorCollection::operator=(const KColorCollection &p) = default;
 
-QColor
-KColorCollection::color(int index) const
+QColor KColorCollection::color(int index) const
 {
     if ((index < 0) || (index >= count())) {
         return QColor();
@@ -214,8 +189,7 @@ KColorCollection::color(int index) const
     return d->colorList[index].color;
 }
 
-int
-KColorCollection::findColor(const QColor &color) const
+int KColorCollection::findColor(const QColor &color) const
 {
     for (int i = 0; i < d->colorList.size(); ++i) {
         if (d->colorList[i].color == color) {
@@ -225,8 +199,7 @@ KColorCollection::findColor(const QColor &color) const
     return -1;
 }
 
-QString
-KColorCollection::name(int index) const
+QString KColorCollection::name(int index) const
 {
     if ((index < 0) || (index >= count())) {
         return QString();
@@ -240,17 +213,13 @@ QString KColorCollection::name(const QColor &color) const
     return name(findColor(color));
 }
 
-int
-KColorCollection::addColor(const QColor &newColor, const QString &newColorName)
+int KColorCollection::addColor(const QColor &newColor, const QString &newColorName)
 {
     d->colorList.append(KColorCollectionPrivate::ColorNode(newColor, newColorName));
     return count() - 1;
 }
 
-int
-KColorCollection::changeColor(int index,
-                              const QColor &newColor,
-                              const QString &newColorName)
+int KColorCollection::changeColor(int index, const QColor &newColor, const QString &newColorName)
 {
     if ((index < 0) || (index >= count())) {
         return -1;
@@ -258,15 +227,12 @@ KColorCollection::changeColor(int index,
 
     KColorCollectionPrivate::ColorNode &node = d->colorList[index];
     node.color = newColor;
-    node.name  = newColorName;
+    node.name = newColorName;
 
     return index;
 }
 
-int KColorCollection::changeColor(const QColor &oldColor,
-                                  const QColor &newColor,
-                                  const QString &newColorName)
+int KColorCollection::changeColor(const QColor &oldColor, const QColor &newColor, const QString &newColorName)
 {
     return changeColor(findColor(oldColor), newColor, newColorName);
 }
-
